@@ -1,5 +1,5 @@
 ###
-# Copyright (c) 2021, The Limnoria Contributors
+# Copyright (c) 2021, Valentin Lorentz
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -52,10 +52,7 @@ __url__ = ""
 from . import config
 from . import plugin
 
-if sys.version_info >= (3, 4):
-    from importlib import reload
-else:
-    from imp import reload
+from importlib import reload
 # In case we're being reloaded.
 reload(config)
 reload(plugin)
