@@ -1021,12 +1021,18 @@ class Databases(registry.SpaceSeparatedListOfStrings):
         v = super(Databases, self).__call__()
         if not v:
             v = ['anydbm', 'dbm', 'cdb', 'flat', 'pickle']
-            if 'sqlite' in sys.modules:
-                v.insert(0, 'sqlite')
-            if 'sqlite3' in sys.modules:
-                v.insert(0, 'sqlite3')
-            if 'sqlalchemy' in sys.modules:
+            try:
+                import sqlalchemy
+            except ImportError:
+                pass
+            else:
                 v.insert(0, 'sqlalchemy')
+            try:
+                import sqlite3
+            except ImportError:
+                pass
+            else:
+                v.insert(0, 'sqlite3')
         return v
 
     def serialize(self):
@@ -1454,7 +1460,7 @@ registerGlobalValue(supybot, 'externalIP',
    empty string, the bot will attempt to find out its IP dynamically (though
    sometimes that doesn't work, hence this variable). This variable is not used
    by Limnoria and its built-in plugins: see supybot.protocols.irc.vhost /
-   supybot.protocols.irc.vhost6 to set the IRC bind host, and
+   supybot.protocols.irc.vhostv6 to set the IRC bind host, and
    supybot.servers.http.hosts4 / supybot.servers.http.hosts6 to set the HTTP
    server bind host.""")))
 
