@@ -77,12 +77,12 @@ class SocketDriver(drivers.IrcDriver, drivers.ServersMixin):
         self.writeCheckTime = None
         self.nextReconnectTime = None
         self.resetDelay()
-        if self.networkGroup.get('ssl').value and 'ssl' not in globals():
+        if self.networkGroup.get('ssl')() and 'ssl' not in globals():
             drivers.log.error('The Socket driver can not connect to SSL '
                               'servers for your Python version.')
             self.ssl = False
         else:
-            self.ssl = self.networkGroup.get('ssl').value
+            self.ssl = self.networkGroup.get('ssl')()
             self.connect()
 
     def getDelay(self):
@@ -325,10 +325,7 @@ class SocketDriver(drivers.IrcDriver, drivers.ServersMixin):
                 self.starttls()
 
             # Suppress this warning for loopback IPs.
-            if sys.version_info[0] < 3:
-                # Backported Python 2 ipaddress demands unicode instead of str
-                address = address.decode('utf-8')
-            elif (not network_config.requireStarttls()) and \
+            if (not network_config.requireStarttls()) and \
                     (not network_config.ssl()) and \
                     (not self.currentServer.force_tls_verification):
 
